@@ -16,12 +16,23 @@ from utilities.forms import (
 
 from django.urls import reverse_lazy
 
-from netbox_storage.models import Filesystem, LogicalVolume, VolumeGroup
+from netbox_storage.models import Filesystem, LogicalVolume, VolumeGroup, Drive
+from virtualization.models import VirtualMachine
 
 
 class LogicalVolumeForm(NetBoxModelForm):
     """Form for creating a new LogicalVolume object."""
-
+    virtual_machine = DynamicModelChoiceField(
+        queryset=VirtualMachine.objects.all(),
+        required=False,
+    )
+    drive = DynamicModelChoiceField(
+        queryset=Drive.objects.all(),
+        query_params={
+            'virtual_machine_id': '$virtual_machine',
+        },
+        help_text="The Storage Cluster of the drive",
+    )
     vg = DynamicModelChoiceField(
         queryset=VolumeGroup.objects.all(),
         label="VG Name",
@@ -56,6 +67,8 @@ class LogicalVolumeForm(NetBoxModelForm):
         model = LogicalVolume
 
         fields = (
+            "virtual_machine",
+            "drive",
             "vg",
             "lv_name",
             "size",
